@@ -24,6 +24,7 @@
 from mingus.core import notes
 from mt_exceptions import NoteFormatError
 from math import log
+from mingus.core import intervals
 
 
 class Note:
@@ -114,6 +115,27 @@ Doesn't change the octave."""
 		"""Calls notes.remove_redundant_accidentals on this note's name."""
 		self.name = notes.remove_redundant_accidentals(self.name)
 
+	def transpose(self, interval, up = True):
+		"""Transposes the note up or down the interval. 
+{{{
+>>> a = Note("A")
+>>> a.transpose("3")
+>>> a
+'C#-5'
+>>> a.transpose("3", False)
+>>> a
+'A-4'
+}}}"""
+		old = self.name
+		self.name = intervals.from_shorthand(self.name, interval, up)
+		if up:
+			if self < Note(old):
+				self.octave += 1
+		else:
+			if self > Note(old):
+				self.octave -= 1
+
+
 	def to_hertz(self, standard_pitch = 440):
 		"""Returns the Note in Hz. The `standard_pitch` argument can be used \
 to set the pitch of A-4, from which the rest is calculated."""
