@@ -18,9 +18,6 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-================================================================================
-	The	Suite class is a datastructure that stores Composition objects.
-
 ================================================================================
 
 """
@@ -29,6 +26,8 @@ from mt_exceptions import UnexpectedObjectError
 
 
 class Suite:
+	"""The	Suite class is a datastructure that stores \
+[refMingusContainersComposition Composition] objects."""
 
 	title = 'Untitled'
 	subtitle = ''
@@ -40,9 +39,9 @@ class Suite:
 		pass
 
 	def add_composition(self, composition):
-		"""Adds a composition to the suite. Raises an 
-		UnexpectedObjectError when the supplied argument is
-		not a Composition object. """
+		"""Adds a [refMingusContainersComposition composition] to the suite. \
+Raises an !UnexpectedObjectError when the supplied argument is \
+not a [refMingusContainersComposition Composition] object. """
 
 		if not ( hasattr ( composition, "tracks") ):
 			raise UnexpectedObjectError,\
