@@ -86,6 +86,7 @@ also deal with lists of chords.
 
 	type_of_chord = chords.determine(chord, True, False, True)
 	for chord in type_of_chord:
+
 		name = chord[0]
 		# Get accidentals
 		a = 1
@@ -100,7 +101,7 @@ also deal with lists of chords.
 		chord_type = chord[a:]
 
 		# Determine chord function
-		interval = intervals.determine(key, name).split(" ")[1]
+		interval_type, interval = intervals.determine(key, name).split(" ")
 		if interval == "unison":
 			func = 'I'
 		elif interval == "second":
@@ -119,20 +120,39 @@ also deal with lists of chords.
 		# Check whether the chord is altered or not
 		for x in expected_chord:
 			if x[0] == func:
+				# Triads
 				if chord_type == x[1]:
 					if not shorthand:
 						func = func_dict[func]
+				# Sevenths
 				elif chord_type == x[2]:
 					if shorthand:
 						func += '7'
 					else:
 						func = func_dict[func] + ' seventh'
+				# Other
 				else:
 					if shorthand:
 						func += chord_type
 					else:
 						func = func_dict[func] + chords.chord_shorthand_meaning[chord_type]
 
+		# Handle b's and #'s (for instance Dbm in key C is bII)
+		if shorthand:
+			if interval_type == "minor":
+				func = "b" + func
+			elif interval_type == "augmented":
+				func = "#" + func
+			elif interval_type == "diminished":
+				func = "bb" + func
+		else:
+			if interval_type == "minor":
+				func = "minor " + func
+			elif interval_type == "augmented":
+				func = "augmented " + func
+			elif interval_type == "diminished":
+				func = "diminished " + func
+
 		# Add to results
 		result.append(func)
 
